<!---
Copyright 2023 The HuggingFace Team. All rights reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
-->

# Overview

Welcome to the 🤗 Optimum-TPU how-to guides!

This page gives you access to a handful of walkthrough scenarios to leverage Google TPUs for your use case:

- [Deploying a Google Cloud TPU instance](./deploy)
- [Deploying a Text-Generation-Inference server on a Google Cloud TPU instance](./serving)
